==================================
Towel - Keeping you DRY since 2010
==================================

.. image:: https://travis-ci.org/matthiask/towel.png?branch=master
   :target: https://travis-ci.org/matthiask/towel

Towel is a collection of tools which make your life easier if you
are building a web application using Django. It contains helpers and
templates for creating paginated, searchable object lists, CRUD
functionality helping you safely and easily create and update objects,
and using Django's own proofed machinery to see what happens when
you want to safely delete objects.

* Towel on github: https://github.com/matthiask/towel/
* Documentation: http://www.feinheit.ch/media/labs/towel/
